package com.tzld.longarticle.recommend.server;

import com.alibaba.fastjson.JSONObject;
import com.tzld.longarticle.recommend.server.model.entity.longArticle.ArticleCategory;
import com.tzld.longarticle.recommend.server.model.entity.longArticle.DatastatScore;
import com.tzld.longarticle.recommend.server.model.vo.IntermediateIndicatorsExport;
import com.tzld.longarticle.recommend.server.model.vo.NewSortStrategyExport;
import com.tzld.longarticle.recommend.server.repository.longArticle.ArticleCategoryRepository;
import com.tzld.longarticle.recommend.server.repository.longArticle.DatastatScoreRepository;
import com.tzld.longarticle.recommend.server.service.recommend.DataDashboardService;
import com.tzld.longarticle.recommend.server.util.DateUtils;
import com.tzld.longarticle.recommend.server.util.feishu.FeiShu;
import lombok.extern.slf4j.Slf4j;
import org.junit.jupiter.api.Test;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.data.util.Pair;
import org.springframework.http.HttpHeaders;

import javax.annotation.Resource;
import java.util.List;
import java.util.Objects;

@SpringBootTest(classes = Application.class)
@Slf4j
public class DataDashboardTest {

    @Resource
    DataDashboardService dataDashboardService;
    @Resource
    DatastatScoreRepository datastatScoreRepository;
    @Resource
    ArticleCategoryRepository articleCategoryRepository;

    @Test
    public void test() {
        List<IntermediateIndicatorsExport> result = dataDashboardService.intermediateIndicatorsData("20241225");
        log.info(JSONObject.toJSONString(result));
    }

    @Test
    public void newSortStrategyData() {
        List<NewSortStrategyExport> result = dataDashboardService.newSortStrategyData("20241222",
                "20241223", "9", 0);
        log.info(JSONObject.toJSONString(result));
    }

    @Test
    public void producePlanAuditExport() {
        List<String> dateStrList = DateUtils.getBeforeDays(null, null, 86);
        dataDashboardService.producePlanAuditExport(dateStrList);
    }

    @Test
    public void delFeishuSheet() {
        List<String> delDateStrList = DateUtils.getBeforeDays(null, null, 14);
        Pair<String, Integer> token = FeiShu.requestAccessToken();
        HttpHeaders httpHeaders = new HttpHeaders();
        httpHeaders.add("Authorization", "Bearer " + token.getFirst());

        dataDashboardService.delFeishuSheet(httpHeaders, "7d4e12", 2, delDateStrList);
    }

    @Test
    public void contentFunnelExport() {
        List<String> dateStrList = DateUtils.getBeforeDays(null, null, 15);
        dataDashboardService.contentFunnelExport(dateStrList);
    }

    @Test
    public void contentGroupFunnelExport() {
        List<String> dateStrList = DateUtils.getBeforeDays(null, null, 7);
        dataDashboardService.contentGroupFunnelExport(dateStrList);
    }

    @Test
    public void datastatScore() {
        List<DatastatScore> scoreList = datastatScoreRepository.getBySourceIdIsNotNull();
        for (DatastatScore score : scoreList) {
            ArticleCategory category = articleCategoryRepository.getByProduceContentIdAndVersion(score.getSourceId(), 2);
            if (Objects.isNull(category)) {
                continue;
            }
            score.setCategory(category.getCategory());
            datastatScoreRepository.save(score);
        }
    }

}
